@@ -17,6 +17,7 @@
 package org.apache.cloudstack.api.response;
 
 import java.util.Date;
+import java.util.Map;
 
 import org.apache.cloudstack.api.ApiConstants;
 import org.apache.cloudstack.api.BaseResponseWithAnnotations;
@@ -155,10 +156,19 @@ public class DiskOfferingResponse extends BaseResponseWithAnnotations {
     @Param(description = "the vsphere storage policy tagged to the disk offering in case of VMware", since = "4.15")
     private String vsphereStoragePolicy;
 
+
     @SerializedName(ApiConstants.DISK_SIZE_STRICTNESS)
     @Param(description = "To allow or disallow the resize operation on the disks created from this disk offering, if the flag is true then resize is not allowed", since = "4.17")
     private Boolean diskSizeStrictness;
 
+    @SerializedName(ApiConstants.ENCRYPT)
+    @Param(description = "Whether disks using this offering will be encrypted on primary storage", since = "4.18")
+    private Boolean encrypt;
+
+    @SerializedName(ApiConstants.DETAILS)
+    @Param(description = "additional key/value details tied with this disk offering", since = "4.17")
+    private Map<String, String> details;
+
     public Boolean getDisplayOffering() {
         return displayOffering;
     }
@@ -375,4 +385,10 @@ public class DiskOfferingResponse extends BaseResponseWithAnnotations {
     public void setDiskSizeStrictness(Boolean diskSizeStrictness) {
         this.diskSizeStrictness = diskSizeStrictness;
     }
+
+    public void setEncrypt(Boolean encrypt) { this.encrypt = encrypt; }
+
+    public void setDetails(Map<String, String> details) {
+        this.details = details;
+    }
 }
