@@ -226,6 +226,10 @@ public class ServiceOfferingResponse extends BaseResponseWithAnnotations {
     @Param(description = "the display text of the disk offering", since = "4.17")
     private String diskOfferingDisplayText;
 
+    @SerializedName(ApiConstants.ENCRYPT_ROOT)
+    @Param(description = "true if virtual machine root disk will be encrypted on storage", since = "4.18")
+    private Boolean encryptRoot;
+
     public ServiceOfferingResponse() {
     }
 
@@ -505,6 +509,7 @@ public class ServiceOfferingResponse extends BaseResponseWithAnnotations {
         this.dynamicScalingEnabled = dynamicScalingEnabled;
     }
 
+
     public Boolean getDiskOfferingStrictness() {
         return diskOfferingStrictness;
     }
@@ -536,4 +541,6 @@ public class ServiceOfferingResponse extends BaseResponseWithAnnotations {
     public String getDiskOfferingDisplayText() {
         return diskOfferingDisplayText;
     }
+
+    public void setEncryptRoot(Boolean encrypt) { this.encryptRoot = encrypt; }
 }
