@@ -20,12 +20,15 @@ package org.apache.cloudstack.backup.veeam;
 import static org.apache.cloudstack.backup.VeeamBackupProvider.BACKUP_IDENTIFIER;
 
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.SocketTimeoutException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.security.KeyManagementException;
 import java.security.NoSuchAlgorithmException;
 import java.security.SecureRandom;
+import java.text.ParseException;
+import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Base64;
@@ -42,6 +45,8 @@ import org.apache.cloudstack.api.ApiErrorCode;
 import org.apache.cloudstack.api.ServerApiException;
 import org.apache.cloudstack.backup.Backup;
 import org.apache.cloudstack.backup.BackupOffering;
+import org.apache.cloudstack.backup.veeam.api.BackupFile;
+import org.apache.cloudstack.backup.veeam.api.BackupFiles;
 import org.apache.cloudstack.backup.veeam.api.BackupJobCloneInfo;
 import org.apache.cloudstack.backup.veeam.api.CreateObjectInJobSpec;
 import org.apache.cloudstack.backup.veeam.api.EntityReferences;
@@ -55,7 +60,10 @@ import org.apache.cloudstack.backup.veeam.api.ObjectsInJob;
 import org.apache.cloudstack.backup.veeam.api.Ref;
 import org.apache.cloudstack.backup.veeam.api.RestoreSession;
 import org.apache.cloudstack.backup.veeam.api.Task;
+import org.apache.cloudstack.backup.veeam.api.VmRestorePoint;
+import org.apache.cloudstack.backup.veeam.api.VmRestorePoints;
 import org.apache.cloudstack.utils.security.SSLUtils;
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.http.HttpHeaders;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
@@ -71,6 +79,7 @@ import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.log4j.Logger;
 
+import com.cloud.utils.NumbersUtil;
 import com.cloud.utils.Pair;
 import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.nio.TrustAllManager;
@@ -90,18 +99,31 @@ public class VeeamClient {
     private final HttpClient httpClient;
     private static final String RESTORE_VM_SUFFIX = "CS-RSTR-";
     private static final String SESSION_HEADER = "X-RestSvcSessionId";
+    private static final String BACKUP_REFERENCE = "BackupReference";
+    private static final String HIERARCHY_ROOT_REFERENCE = "HierarchyRootReference";
+    private static final String REPOSITORY_REFERENCE = "RepositoryReference";
+    private static final String RESTORE_POINT_REFERENCE = "RestorePointReference";
+    private static final String BACKUP_FILE_REFERENCE = "BackupFileReference";
+    private static final SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");
+    private static final SimpleDateFormat newDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+
 
     private String veeamServerIp;
+    private final Integer veeamServerVersion;
     private String veeamServerUsername;
     private String veeamServerPassword;
     private String veeamSessionId = null;
-    private int restoreTimeout;
+    private final int restoreTimeout;
     private final int veeamServerPort = 22;
+    private final int taskPollInterval;
+    private final int taskPollMaxRetry;
 
-    public VeeamClient(final String url, final String username, final String password, final boolean validateCertificate, final int timeout,
-            final int restoreTimeout) throws URISyntaxException, NoSuchAlgorithmException, KeyManagementException {
+    public VeeamClient(final String url, final Integer version, final String username, final String password, final boolean validateCertificate, final int timeout,
+            final int restoreTimeout, final int taskPollInterval, final int taskPollMaxRetry) throws URISyntaxException, NoSuchAlgorithmException, KeyManagementException {
         this.apiURI = new URI(url);
         this.restoreTimeout = restoreTimeout;
+        this.taskPollInterval = taskPollInterval;
+        this.taskPollMaxRetry = taskPollMaxRetry;
 
         final RequestConfig config = RequestConfig.custom()
                 .setConnectTimeout(timeout * 1000)
@@ -125,6 +147,7 @@ public class VeeamClient {
 
         authenticate(username, password);
         setVeeamSshCredentials(this.apiURI.getHost(), username, password);
+        this.veeamServerVersion = (version != null && version != 0) ? version : getVeeamServerVersion();
     }
 
     protected void setVeeamSshCredentials(String hostIp, String username, String password) {
@@ -135,7 +158,7 @@ public class VeeamClient {
 
     private void authenticate(final String username, final String password) {
         // https://helpcenter.veeam.com/docs/backup/rest/http_authentication.html?ver=95u4
-        final HttpPost request = new HttpPost(apiURI.toString() + "/sessionMngr/?v=v1_4");
+        final HttpPost request = new HttpPost(apiURI.toString() + "/sessionMngr/?v=latest");
         request.setHeader(HttpHeaders.AUTHORIZATION, "Basic " + Base64.getEncoder().encodeToString((username + ":" + password).getBytes()));
         try {
             final HttpResponse response = httpClient.execute(request);
@@ -158,6 +181,26 @@ public class VeeamClient {
         }
     }
 
+    protected Integer getVeeamServerVersion() {
+        final List<String> cmds = Arrays.asList(
+                "$InstallPath = Get-ItemProperty -Path 'HKLM:\\Software\\Veeam\\Veeam Backup and Replication\\' ^| Select -ExpandProperty CorePath",
+                "Add-Type -LiteralPath \\\"$InstallPath\\Veeam.Backup.Configuration.dll\\\"",
+                "$ProductData = [Veeam.Backup.Configuration.BackupProduct]::Create()",
+                "$Version = $ProductData.ProductVersion.ToString()",
+                "if ($ProductData.MarketName -ne '') {$Version += \\\" $($ProductData.MarketName)\\\"}",
+                "$Version"
+        );
+        Pair<Boolean, String> response = executePowerShellCommands(cmds);
+        if (response == null || !response.first() || response.second() == null || StringUtils.isBlank(response.second().trim())) {
+            LOG.error("Failed to get veeam server version, using default version");
+            return 0;
+        } else {
+            Integer majorVersion = NumbersUtil.parseInt(response.second().trim().split("\\.")[0], 0);
+            LOG.info(String.format("Veeam server full version is %s, major version is %s", response.second().trim(), majorVersion));
+            return majorVersion;
+        }
+    }
+
     private void checkResponseOK(final HttpResponse response) {
         if (response.getStatusLine().getStatusCode() == HttpStatus.SC_NO_CONTENT) {
             LOG.debug("Requested Veeam resource does not exist");
@@ -238,7 +281,7 @@ public class VeeamClient {
             final ObjectMapper objectMapper = new XmlMapper();
             final EntityReferences references = objectMapper.readValue(response.getEntity().getContent(), EntityReferences.class);
             for (final Ref ref : references.getRefs()) {
-                if (ref.getName().equals(vmwareDcName) && ref.getType().equals("HierarchyRootReference")) {
+                if (ref.getName().equals(vmwareDcName) && ref.getType().equals(HIERARCHY_ROOT_REFERENCE)) {
                     return ref.getUid();
                 }
             }
@@ -286,7 +329,7 @@ public class VeeamClient {
 
     private boolean checkTaskStatus(final HttpResponse response) throws IOException {
         final Task task = parseTaskResponse(response);
-        for (int i = 0; i < 120; i++) {
+        for (int i = 0; i < this.taskPollMaxRetry; i++) {
             final HttpResponse taskResponse = get("/tasks/" + task.getTaskId());
             final Task polledTask = parseTaskResponse(taskResponse);
             if (polledTask.getState().equals("Finished")) {
@@ -309,7 +352,7 @@ public class VeeamClient {
                 throw new CloudRuntimeException("Failed to assign VM to backup offering due to: " + polledTask.getResult().getMessage());
             }
             try {
-                Thread.sleep(5000);
+                Thread.sleep(this.taskPollInterval * 1000);
             } catch (InterruptedException e) {
                 LOG.debug("Failed to sleep while polling for Veeam task status due to: ", e);
             }
@@ -324,6 +367,10 @@ public class VeeamClient {
             if (session.getResult().equals("Success")) {
                 return true;
             }
+            if (session.getResult().equalsIgnoreCase("Failed")) {
+                String sessionUid = session.getUid();
+                throw new CloudRuntimeException(String.format("Restore job [%s] failed.", sessionUid));
+            }
             try {
                 Thread.sleep(1000);
             } catch (InterruptedException ignored) {
@@ -355,7 +402,7 @@ public class VeeamClient {
             final ObjectMapper objectMapper = new XmlMapper();
             final EntityReferences references = objectMapper.readValue(response.getEntity().getContent(), EntityReferences.class);
             for (final Ref ref : references.getRefs()) {
-                if (ref.getType().equals("RepositoryReference") && ref.getName().equals(repositoryName)) {
+                if (ref.getType().equals(REPOSITORY_REFERENCE) && ref.getName().equals(repositoryName)) {
                     return ref;
                 }
             }
@@ -368,7 +415,7 @@ public class VeeamClient {
 
     protected String getRepositoryNameFromJob(String backupName) {
         final List<String> cmds = Arrays.asList(
-                String.format("$Job = Get-VBRJob -name \"%s\"", backupName),
+                String.format("$Job = Get-VBRJob -name '%s'", backupName),
                 "$Job.GetBackupTargetRepository() ^| select Name ^| Format-List"
         );
         Pair<Boolean, String> result = executePowerShellCommands(cmds);
@@ -376,7 +423,7 @@ public class VeeamClient {
             throw new CloudRuntimeException(String.format("Failed to get Repository Name from Job [name: %s].", backupName));
         }
 
-        for (String block : result.second().split("\n\n")) {
+        for (String block : result.second().split("\r\n")) {
            if (block.matches("Name(\\s)+:(.)*")) {
                return block.split(":")[1].trim();
            }
@@ -553,7 +600,12 @@ public class VeeamClient {
      */
     protected String transformPowerShellCommandList(List<String> cmds) {
         StringJoiner joiner = new StringJoiner(";");
-        joiner.add("PowerShell Add-PSSnapin VeeamPSSnapin");
+        if (isLegacyServer()) {
+            joiner.add("PowerShell Add-PSSnapin VeeamPSSnapin");
+        } else {
+            joiner.add("PowerShell Import-Module Veeam.Backup.PowerShell -WarningAction SilentlyContinue");
+            joiner.add("$ProgressPreference='SilentlyContinue'");
+        }
         for (String cmd : cmds) {
             joiner.add(cmd);
         }
@@ -584,22 +636,20 @@ public class VeeamClient {
 
     public boolean setJobSchedule(final String jobName) {
         Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
-                String.format("$job = Get-VBRJob -Name \"%s\"", jobName),
+                String.format("$job = Get-VBRJob -Name '%s'", jobName),
                 "if ($job) { Set-VBRJobSchedule -Job $job -Daily -At \"11:00\" -DailyKind Weekdays }"
         ));
-        return result.first() && !result.second().isEmpty() && !result.second().contains(FAILED_TO_DELETE);
+        return result != null && result.first() && !result.second().isEmpty() && !result.second().contains(FAILED_TO_DELETE);
     }
 
     public boolean deleteJobAndBackup(final String jobName) {
         Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
-                String.format("$job = Get-VBRJob -Name \"%s\"", jobName),
+                String.format("$job = Get-VBRJob -Name '%s'", jobName),
                 "if ($job) { Remove-VBRJob -Job $job -Confirm:$false }",
-                String.format("$backup = Get-VBRBackup -Name \"%s\"", jobName),
-                "if ($backup) { Remove-VBRBackup -Backup $backup -FromDisk -Confirm:$false }",
-                "$repo = Get-VBRBackupRepository",
-                "Sync-VBRBackupRepository -Repository $repo"
+                String.format("$backup = Get-VBRBackup -Name '%s'", jobName),
+                "if ($backup) { Remove-VBRBackup -Backup $backup -FromDisk -Confirm:$false }"
         ));
-        return result.first() && !result.second().contains(FAILED_TO_DELETE);
+        return result != null && result.first() && !result.second().contains(FAILED_TO_DELETE);
     }
 
     public boolean deleteBackup(final String restorePointId) {
@@ -607,43 +657,135 @@ public class VeeamClient {
         Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
                 String.format("$restorePoint = Get-VBRRestorePoint ^| Where-Object { $_.Id -eq '%s' }", restorePointId),
                 "if ($restorePoint) { Remove-VBRRestorePoint -Oib $restorePoint -Confirm:$false",
-                    "$repo = Get-VBRBackupRepository",
-                    "Sync-VBRBackupRepository -Repository $repo",
                 "} else { ",
-                    " Write-Output \"Failed to delete\"",
+                    " Write-Output 'Failed to delete'",
                     " Exit 1",
                 "}"
         ));
-        return result.first() && !result.second().contains(FAILED_TO_DELETE);
+        return result != null && result.first() && !result.second().contains(FAILED_TO_DELETE);
+    }
+
+    public boolean syncBackupRepository() {
+        LOG.debug("Trying to sync backup repository.");
+        Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
+                "$repo = Get-VBRBackupRepository",
+                "$Syncs = Sync-VBRBackupRepository -Repository $repo",
+                "while ((Get-VBRSession -ID $Syncs.ID).Result -ne 'Success') { Start-Sleep -Seconds 10 }"
+        ));
+        LOG.debug("Done syncing backup repository.");
+        return result != null && result.first();
     }
 
     public Map<String, Backup.Metric> getBackupMetrics() {
+        if (isLegacyServer()) {
+            return getBackupMetricsLegacy();
+        } else {
+            return getBackupMetricsViaVeeamAPI();
+        }
+    }
+
+    public Map<String, Backup.Metric> getBackupMetricsViaVeeamAPI() {
+        LOG.debug("Trying to get backup metrics via Veeam B&R API");
+
+        try {
+            final HttpResponse response = get(String.format("/backupFiles?format=Entity"));
+            checkResponseOK(response);
+            return processHttpResponseForBackupMetrics(response.getEntity().getContent());
+        } catch (final IOException e) {
+            LOG.error("Failed to get backup metrics via Veeam B&R API due to:", e);
+            checkResponseTimeOut(e);
+        }
+        return new HashMap<>();
+    }
+
+    protected Map<String, Backup.Metric> processHttpResponseForBackupMetrics(final InputStream content) {
+        Map<String, Backup.Metric> metrics = new HashMap<>();
+        try {
+            final ObjectMapper objectMapper = new XmlMapper();
+            final BackupFiles backupFiles = objectMapper.readValue(content, BackupFiles.class);
+            if (backupFiles == null || CollectionUtils.isEmpty(backupFiles.getBackupFiles())) {
+                throw new CloudRuntimeException("Could not get backup metrics via Veeam B&R API");
+            }
+            for (final BackupFile backupFile : backupFiles.getBackupFiles()) {
+                String vmUuid = null;
+                String backupName = null;
+                List<Link> links = backupFile.getLink();
+                for (Link link : links) {
+                    if (BACKUP_REFERENCE.equals(link.getType())) {
+                        backupName = link.getName();
+                        break;
+                    }
+                }
+                if (backupName != null && backupName.contains(BACKUP_IDENTIFIER)) {
+                    final String[] names = backupName.split(BACKUP_IDENTIFIER);
+                    if (names.length > 1) {
+                        vmUuid = names[1];
+                    }
+                }
+                if (vmUuid == null) {
+                    continue;
+                }
+                if (vmUuid.contains(" - ")) {
+                    vmUuid = vmUuid.split(" - ")[0];
+                }
+                Long usedSize = 0L;
+                Long dataSize = 0L;
+                if (metrics.containsKey(vmUuid)) {
+                    usedSize = metrics.get(vmUuid).getBackupSize();
+                    dataSize = metrics.get(vmUuid).getDataSize();
+                }
+                if (backupFile.getBackupSize() != null) {
+                    usedSize += Long.valueOf(backupFile.getBackupSize());
+                }
+                if (backupFile.getDataSize() != null) {
+                    dataSize += Long.valueOf(backupFile.getDataSize());
+                }
+                metrics.put(vmUuid, new Backup.Metric(usedSize, dataSize));
+            }
+        } catch (final IOException e) {
+            LOG.error("Failed to process response to get backup metrics via Veeam B&R API due to:", e);
+            checkResponseTimeOut(e);
+        }
+        return metrics;
+    }
+
+    public Map<String, Backup.Metric> getBackupMetricsLegacy() {
         final String separator = "=====";
         final List<String> cmds = Arrays.asList(
-            "$backups = Get-VBRBackup",
-            "foreach ($backup in $backups) {" +
-               "$backup.JobName;" +
-               "$storageGroups = $backup.GetStorageGroups();" +
-               "foreach ($group in $storageGroups) {" +
-                    "$usedSize = 0;" +
-                    "$dataSize = 0;" +
-                    "$sizePerStorage = $group.GetStorages().Stats.BackupSize;" +
-                    "$dataPerStorage = $group.GetStorages().Stats.DataSize;" +
-                    "foreach ($size in $sizePerStorage) {" +
-                        "$usedSize += $size;" +
-                    "}" +
-                    "foreach ($size in $dataPerStorage) {" +
-                        "$dataSize += $size;" +
-                    "}" +
-                    "$usedSize;" +
-                    "$dataSize;" +
-               "}" +
-               "echo \"" + separator + "\"" +
-            "}"
+                "$backups = Get-VBRBackup",
+                "foreach ($backup in $backups) {" +
+                        "    $backup.JobName;" +
+                        "    $storageGroups = $backup.GetStorageGroups();" +
+                        "    foreach ($group in $storageGroups) {" +
+                        "        $usedSize = 0;" +
+                        "        $dataSize = 0;" +
+                        "        $sizePerStorage = $group.GetStorages().Stats.BackupSize;" +
+                        "        $dataPerStorage = $group.GetStorages().Stats.DataSize;" +
+                        "        foreach ($size in $sizePerStorage) {" +
+                        "            $usedSize += $size;" +
+                        "        }" +
+                        "        foreach ($size in $dataPerStorage) {" +
+                        "            $dataSize += $size;" +
+                        "        }" +
+                        "        $usedSize;" +
+                        "        $dataSize;" +
+                        "    }" +
+                        "    echo \"" + separator + "\"" +
+                        "}"
         );
         Pair<Boolean, String> response = executePowerShellCommands(cmds);
+        if (response == null || !response.first()) {
+            throw new CloudRuntimeException("Failed to get backup metrics via PowerShell command");
+        }
+        return processPowerShellResultForBackupMetrics(response.second());
+    }
+
+    protected Map<String, Backup.Metric> processPowerShellResultForBackupMetrics(final String result) {
+        LOG.debug("Processing powershell result: " + result);
+
+        final String separator = "=====";
         final Map<String, Backup.Metric> sizes = new HashMap<>();
-        for (final String block : response.second().split(separator + "\r\n")) {
+        for (final String block : result.split(separator + "\r\n")) {
             final String[] parts = block.split("\r\n");
             if (parts.length != 3) {
                 continue;
@@ -677,9 +819,9 @@ public class VeeamClient {
         return new Backup.RestorePoint(id, created, type);
     }
 
-    public List<Backup.RestorePoint> listRestorePoints(String backupName, String vmInternalName) {
+    public List<Backup.RestorePoint> listRestorePointsLegacy(String backupName, String vmInternalName) {
         final List<String> cmds = Arrays.asList(
-                String.format("$backup = Get-VBRBackup -Name \"%s\"", backupName),
+                String.format("$backup = Get-VBRBackup -Name '%s'", backupName),
                 String.format("if ($backup) { $restore = (Get-VBRRestorePoint -Backup:$backup -Name \"%s\" ^| Where-Object {$_.IsConsistent -eq $true})", vmInternalName),
                 "if ($restore) { $restore ^| Format-List } }"
         );
@@ -700,6 +842,71 @@ public class VeeamClient {
         return restorePoints;
     }
 
+    public List<Backup.RestorePoint> listRestorePoints(String backupName, String vmInternalName) {
+        if (isLegacyServer()) {
+            return listRestorePointsLegacy(backupName, vmInternalName);
+        } else {
+            return listVmRestorePointsViaVeeamAPI(vmInternalName);
+        }
+    }
+
+    public List<Backup.RestorePoint> listVmRestorePointsViaVeeamAPI(String vmInternalName) {
+        LOG.debug(String.format("Trying to list VM restore points via Veeam B&R API for VM %s: ", vmInternalName));
+
+        try {
+            final HttpResponse response = get(String.format("/vmRestorePoints?format=Entity"));
+            checkResponseOK(response);
+            return processHttpResponseForVmRestorePoints(response.getEntity().getContent(), vmInternalName);
+        } catch (final IOException e) {
+            LOG.error("Failed to list VM restore points via Veeam B&R API due to:", e);
+            checkResponseTimeOut(e);
+        }
+        return new ArrayList<>();
+    }
+
+    public List<Backup.RestorePoint> processHttpResponseForVmRestorePoints(InputStream content, String vmInternalName) {
+        List<Backup.RestorePoint> vmRestorePointList = new ArrayList<>();
+        try {
+            final ObjectMapper objectMapper = new XmlMapper();
+            final VmRestorePoints vmRestorePoints = objectMapper.readValue(content, VmRestorePoints.class);
+            if (vmRestorePoints == null) {
+                throw new CloudRuntimeException("Could not get VM restore points via Veeam B&R API");
+            }
+            for (final VmRestorePoint vmRestorePoint : vmRestorePoints.getVmRestorePoints()) {
+                LOG.debug(String.format("Processing VM restore point Name=%s, VmDisplayName=%s for vm name=%s",
+                        vmRestorePoint.getName(), vmRestorePoint.getVmDisplayName(), vmInternalName));
+                if (!vmInternalName.equals(vmRestorePoint.getVmDisplayName())) {
+                    continue;
+                }
+                boolean isReady = true;
+                List<Link> links = vmRestorePoint.getLink();
+                for (Link link : links) {
+                    if (Arrays.asList(BACKUP_FILE_REFERENCE, RESTORE_POINT_REFERENCE).contains(link.getType()) && !link.getRel().equals("Up")) {
+                        LOG.info(String.format("The VM restore point is not ready. Reference: %s, state: %s", link.getType(), link.getRel()));
+                        isReady = false;
+                        break;
+                    }
+                }
+                if (!isReady) {
+                    continue;
+                }
+                String vmRestorePointId = vmRestorePoint.getUid().substring(vmRestorePoint.getUid().lastIndexOf(':') + 1);
+                String created = formatDate(vmRestorePoint.getCreationTimeUtc());
+                String type = vmRestorePoint.getPointType();
+                LOG.debug(String.format("Adding restore point %s, %s, %s", vmRestorePointId, created, type));
+                vmRestorePointList.add(new Backup.RestorePoint(vmRestorePointId, created, type));
+            }
+        } catch (final IOException | ParseException e) {
+            LOG.error("Failed to process response to get VM restore points via Veeam B&R API due to:", e);
+            checkResponseTimeOut(e);
+        }
+        return vmRestorePointList;
+    }
+
+    private String formatDate(String date) throws ParseException {
+        return newDateFormat.format(dateFormat.parse(StringUtils.substring(date, 0, 19)));
+    }
+
     public Pair<Boolean, String> restoreVMToDifferentLocation(String restorePointId, String hostIp, String dataStoreUuid) {
         final String restoreLocation = RESTORE_VM_SUFFIX + UUID.randomUUID().toString();
         final String datastoreId = dataStoreUuid.replace("-","");
@@ -717,4 +924,8 @@ public class VeeamClient {
         }
         return new Pair<>(result.first(), restoreLocation);
     }
+
+    private boolean isLegacyServer() {
+        return this.veeamServerVersion != null && (this.veeamServerVersion > 0 && this.veeamServerVersion < 11);
+    }
 }
