@@ -24,7 +24,11 @@ import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
+import java.lang.reflect.Field;
+import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.UUID;
 
 import org.apache.cloudstack.acl.ControlledEntity;
@@ -37,10 +41,11 @@ import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotInfo;
 import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotService;
 import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotStrategy;
 import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotStrategy.SnapshotOperation;
-import org.apache.cloudstack.snapshot.SnapshotHelper;
 import org.apache.cloudstack.engine.subsystem.api.storage.StorageStrategyFactory;
 import org.apache.cloudstack.engine.subsystem.api.storage.VolumeDataFactory;
 import org.apache.cloudstack.engine.subsystem.api.storage.VolumeInfo;
+import org.apache.cloudstack.framework.config.ConfigKey;
+import org.apache.cloudstack.snapshot.SnapshotHelper;
 import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.SnapshotDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.SnapshotDataStoreVO;
@@ -49,12 +54,21 @@ import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.mockito.BDDMockito;
 import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
 import org.mockito.Spy;
+import org.mockito.verification.VerificationMode;
+import org.powermock.api.mockito.PowerMockito;
+import org.powermock.core.classloader.annotations.PrepareForTest;
+import org.powermock.modules.junit4.PowerMockRunner;
 
 import com.cloud.configuration.Resource.ResourceType;
+import com.cloud.dc.DataCenter;
+import com.cloud.dc.DataCenterVO;
+import com.cloud.dc.dao.DataCenterDao;
 import com.cloud.exception.InvalidParameterValueException;
 import com.cloud.exception.ResourceAllocationException;
 import com.cloud.hypervisor.Hypervisor;
@@ -88,15 +102,6 @@ import com.cloud.vm.dao.UserVmDao;
 import com.cloud.vm.snapshot.VMSnapshot;
 import com.cloud.vm.snapshot.VMSnapshotVO;
 import com.cloud.vm.snapshot.dao.VMSnapshotDao;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.Map;
-import org.junit.runner.RunWith;
-import org.mockito.BDDMockito;
-import org.mockito.verification.VerificationMode;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest(GlobalLock.class)
@@ -171,6 +176,8 @@ public class SnapshotManagerTest {
 
     @Mock
     TaggedResourceService taggedResourceServiceMock;
+    @Mock
+    DataCenterDao dataCenterDao;
 
     SnapshotPolicyVO snapshotPolicyVoInstance;
 
@@ -207,6 +214,7 @@ public class SnapshotManagerTest {
         _snapshotMgr._snapshotPolicyDao = snapshotPolicyDaoMock;
         _snapshotMgr._snapSchedMgr = snapshotSchedulerMock;
         _snapshotMgr.taggedResourceService = taggedResourceServiceMock;
+        _snapshotMgr.dataCenterDao = dataCenterDao;
 
         when(_snapshotDao.findById(anyLong())).thenReturn(snapshotMock);
         when(snapshotMock.getVolumeId()).thenReturn(TEST_VOLUME_ID);
@@ -533,4 +541,38 @@ public class SnapshotManagerTest {
           Mockito.any(DateUtil.IntervalType.class), Mockito.anyInt(), Mockito.anyBoolean(), Mockito.anyBoolean());
         Mockito.verify(_snapshotMgr, timesVerification).createTagsForSnapshotPolicy(Mockito.any(), Mockito.any());
     }
+
+    private void mockForBackupSnapshotToSecondaryZoneTest(final Boolean configValue, final DataCenter.Type dcType) {
+        try {
+            Field f = ConfigKey.class.getDeclaredField("_value");
+            f.setAccessible(true);
+            f.set(SnapshotInfo.BackupSnapshotAfterTakingSnapshot, configValue);
+        } catch (NoSuchFieldException | IllegalAccessException e) {
+            Assert.fail(String.format("Failed to override config: %s", e.getMessage()));
+        }
+        DataCenterVO dc = Mockito.mock(DataCenterVO.class);
+        Mockito.when(dc.getType()).thenReturn(dcType);
+        Mockito.when(dataCenterDao.findById(1L)).thenReturn(dc);
+    }
+    @Test
+    public void testIsBackupSnapshotToSecondaryForCoreZoneNullConfig() {
+        mockForBackupSnapshotToSecondaryZoneTest(null, DataCenter.Type.Core);
+        Assert.assertTrue(_snapshotMgr.isBackupSnapshotToSecondaryForZone(1L));
+    }
+    @Test
+    public void testIsBackupSnapshotToSecondaryForCoreZoneEnabledConfig() {
+        mockForBackupSnapshotToSecondaryZoneTest(true, DataCenter.Type.Core);
+        Assert.assertTrue(_snapshotMgr.isBackupSnapshotToSecondaryForZone(1L));
+    }
+    @Test
+    public void testIsBackupSnapshotToSecondaryForCoreZoneDisabledConfig() {
+        mockForBackupSnapshotToSecondaryZoneTest(false, DataCenter.Type.Core);
+        Assert.assertFalse(_snapshotMgr.isBackupSnapshotToSecondaryForZone(1L));
+    }
+
+    @Test
+    public void testIsBackupSnapshotToSecondaryForEdgeZone() {
+        mockForBackupSnapshotToSecondaryZoneTest(true, DataCenter.Type.Edge);
+        Assert.assertFalse(_snapshotMgr.isBackupSnapshotToSecondaryForZone(1L));
+    }
 }
